==> haskell-genvalidity-hspec-1.0.0.3-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-hspec
version:              1.0.0.3
visibility:           public
id:                   genvalidity-hspec-1.0.0.3-Fs7EucIv7Er32xn2M8s8BG
key:                  genvalidity-hspec-1.0.0.3-Fs7EucIv7Er32xn2M8s8BG
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  3bad691e075f243f519212b27a97d7b1
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.2.8/site-local/genvalidity-hspec-1.0.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/genvalidity-hspec-1.0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.3-Fs7EucIv7Er32xn2M8s8BG
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    genvalidity-1.1.0.0-KBSm8zqLtleKRPnpRQIZMH
    genvalidity-property-1.0.0.0-HJ7ybGkITMq5pu5lASoKwd
    hspec-2.10.9-KuS4B4SgPwm179O4lsuAOc
    hspec-core-2.10.9-EPbsf4CX1VNHe1gcsgpM0I transformers-0.5.6.2
    validity-0.12.0.2-8mLDnzAf1JNLFCf9Kp2tpt

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-hspec-1.0.0.3-42.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.3
visibility:           public
id:                   genvalidity-hspec-1.0.0.3-J6TKj5osUHsJa1eXEHgNsn
key:                  genvalidity-hspec-1.0.0.3-J6TKj5osUHsJa1eXEHgNsn
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  7a1bfdd8d377a0764c7e4e22a284e9aa
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.3-J6TKj5osUHsJa1eXEHgNsn
depends:
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O base-4.17.2.1
    genvalidity-1.1.1.0-JlHFxqNtJUTEO4hRrJMCRP
    genvalidity-property-1.0.0.0-57buIT55nlp7qysNFhFzvn
    hspec-2.10.9-8PqvxiZVgrL4DvXVyNhtnS
    hspec-core-2.10.9-JXA91YXBxjG5KLMnkMduaR transformers-0.5.6.2
    validity-0.12.1.0-FIzFF3lSpT53uOKNr6m0c7

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
